[llvm] [AsmParser] Track value references and function arguments (PR #174566)
Mikael Holmen via llvm-commits
llvm-commits at lists.llvm.org
Thu Feb 5 03:12:48 PST 2026
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,
Albert =?utf-8?q?Havliček?= <ahavlicek at azul.com>,Bertik23
<39457484+Bertik23 at users.noreply.github.com>,Bertik23
<39457484+Bertik23 at users.noreply.github.com>
Message-ID:
In-Reply-To: <llvm.org/llvm/llvm-project/pull/174566 at github.com>
mikaelholmen wrote:
Regarding regressed execution times I've also seen significantly increased lit test times with this patch.
E.g.
```
llvm-lit -a test/CodeGen/SPIRV/extensions/SPV_INTEL_long_composites/long-spec-const-composite.ll
```
took 3-4 seconds before this patch and around 48 seconds with it.
For EXPENSIVE_CHECKS built binaries the time went from ~2 to ~11minutes.
For
```
CodeGen/AMDGPU/amdgcn.bitcast.1024bit.ll
```
EXPENSIVE_CHECKS execution times went from ~2.5 to ~4minutes.
https://github.com/llvm/llvm-project/pull/174566
More information about the llvm-commits
mailing list